==> haskell-authenticate-1.3.4-169-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate
version: 1.3.4
id: authenticate-1.3.4-4SNRpcfuNWgGHHajEnON0I
key: authenticate-1.3.4-4SNRpcfuNWgGHHajEnON0I
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.
category: Web
abi: 3663b6fe081bc456042732086bf8002b
exposed: True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow
hidden-modules: Web.Authenticate.Internal OpenId2.Discovery
                OpenId2.Normalization OpenId2.Types OpenId2.XRDS
import-dirs: /usr/lib/ghc-8.4.3/site-local/authenticate-1.3.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/authenticate-1.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/authenticate-1.3.4
hs-libraries: HSauthenticate-1.3.4-4SNRpcfuNWgGHHajEnON0I
depends:
    aeson-1.4.0.0-CakggGCi8AH730RFzdp4vh
    attoparsec-0.13.2.2-LRi8ukEwwi1GyId6oqTEFJ base-4.11.1.0
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    conduit-1.3.0.3-69KoIVNx0TVLvOnjPWsVja containers-0.5.11.0
    http-conduit-2.3.2-Fc3FewYwyrU2z9C3xj29pG
    http-types-0.12.1-BvzC7WDeWNh7Q1bvrgnPmB
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    resourcet-1.2.1-I5oi84Fds3fEsALgoQoNDA
    tagstream-conduit-0.5.5.3-90lpuuR59SB40naXU2ITPd text-1.2.3.0
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd
    xml-conduit-1.8.0-B3jRhN4FymgBxETDF0MfEe
abi-depends: aeson-1.4.0.0-CakggGCi8AH730RFzdp4vh=7bc5561c9bccdf225964aec1dc0920a0
             attoparsec-0.13.2.2-LRi8ukEwwi1GyId6oqTEFJ=b8f8a17746566009aae6e9799affc625
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             conduit-1.3.0.3-69KoIVNx0TVLvOnjPWsVja=95a17956f651b4cddf6ae026fd262ccd
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             http-conduit-2.3.2-Fc3FewYwyrU2z9C3xj29pG=587475ff466ed617e153f3e7b1f159a8
             http-types-0.12.1-BvzC7WDeWNh7Q1bvrgnPmB=302ec39836eeed635681d48972d58b60
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
             resourcet-1.2.1-I5oi84Fds3fEsALgoQoNDA=dcbdc81671b5884f063aea7a644e0575
             tagstream-conduit-0.5.5.3-90lpuuR59SB40naXU2ITPd=29fa23341dd2a50307f6b67ac1271e73
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd=4d1dd6bd73dbf55dc13ef767664a6e82
             xml-conduit-1.8.0-B3jRhN4FymgBxETDF0MfEe=00626b7a116849b4cca79b99206c6ebd
haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
haddock-html: /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-1.3.4-171-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate
version: 1.3.4
id: authenticate-1.3.4-Li7hg33ZNC93EZrnDCWu7O
key: authenticate-1.3.4-Li7hg33ZNC93EZrnDCWu7O
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.
category: Web
abi: 244aa6d0905e9e107c092cae662b3e31
exposed: True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow
hidden-modules: Web.Authenticate.Internal OpenId2.Discovery
                OpenId2.Normalization OpenId2.Types OpenId2.XRDS
import-dirs: /usr/lib/ghc-8.4.3/site-local/authenticate-1.3.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/authenticate-1.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/authenticate-1.3.4
hs-libraries: HSauthenticate-1.3.4-Li7hg33ZNC93EZrnDCWu7O
depends:
    aeson-1.4.0.0-EgUTCbIlE19378rsR2i9zV
    attoparsec-0.13.2.2-LRi8ukEwwi1GyId6oqTEFJ base-4.11.1.0
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    conduit-1.3.0.3-69KoIVNx0TVLvOnjPWsVja containers-0.5.11.0
    http-conduit-2.3.2-1aZWoMRsYRpKfDlvvbX8BU
    http-types-0.12.1-BvzC7WDeWNh7Q1bvrgnPmB
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    resourcet-1.2.1-I5oi84Fds3fEsALgoQoNDA
    tagstream-conduit-0.5.5.3-BIMGWeLpJFgDx77hCliNTZ text-1.2.3.0
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd
    xml-conduit-1.8.0-B3jRhN4FymgBxETDF0MfEe
abi-depends: aeson-1.4.0.0-EgUTCbIlE19378rsR2i9zV=8e4d597de977510ba6167651bfbacc4c
             attoparsec-0.13.2.2-LRi8ukEwwi1GyId6oqTEFJ=b8f8a17746566009aae6e9799affc625
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             conduit-1.3.0.3-69KoIVNx0TVLvOnjPWsVja=95a17956f651b4cddf6ae026fd262ccd
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             http-conduit-2.3.2-1aZWoMRsYRpKfDlvvbX8BU=d9058125d1363db51383405558893120
             http-types-0.12.1-BvzC7WDeWNh7Q1bvrgnPmB=302ec39836eeed635681d48972d58b60
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
             resourcet-1.2.1-I5oi84Fds3fEsALgoQoNDA=dcbdc81671b5884f063aea7a644e0575
             tagstream-conduit-0.5.5.3-BIMGWeLpJFgDx77hCliNTZ=4237ed427b0379da9cfc71b50b0c408d
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd=4d1dd6bd73dbf55dc13ef767664a6e82
             xml-conduit-1.8.0-B3jRhN4FymgBxETDF0MfEe=00626b7a116849b4cca79b99206c6ebd
haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
haddock-html: /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
